<?php
/*
Plugin Name: WP SyntaxHighlighter
Plugin URI: http://www.near-mint.com/blog/software
Description: This plugin is code syntax highlighter based on <a href="http://alexgorbatchev.com/SyntaxHighlighter/">SyntaxHighlighter</a> ver. 3.0.83 and ver. 2.1.382. Supported languages: Bash, C++, CSS, Delphi, Java, JavaScript, Perl, PHP, Python, Ruby, SQL, VB, XML, XHTML and HTML etc.
Version: 1.0
Author: Redcocker
Author URI: http://www.near-mint.com/blog/
Text Domain: wp_sh
Domain Path: /locale/
*/
/* 
Date of release: Ver. 1.0 2011/5/3
Includes: SyntaxHighlighter ver. 3.0.83 and ver. 2.1.382 licensed under the MIT and GPL v3 licenses.
License: GPL v2(Except 'SyntaxHighlighter' libraries)
*/
/*  Copyright 2011 M. Sumitomo

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/
load_plugin_textdomain('wp_sh', false, 'wp-syntaxhighlighter/locale');
$plugin_url = plugin_dir_url( __FILE__ ); 

add_action('admin_menu', 'wp_sh_register_menu_item');
add_filter( 'plugin_action_links', 'wp_sh_setting_link', 10, 2 );

function wp_sh_add_admin_footer(){ //show plugin info in the footer
	$plugin_data = get_plugin_data(__FILE__);
	printf('%1$s by %2$s<br />', $plugin_data['Title'].' '.$plugin_data['Version'], $plugin_data['Author']);
}

function wp_sh_register_menu_item() {
	register_setting( 'wp_sh_settings_group', 'wp_sh_version');
	register_setting( 'wp_sh_settings_group', 'wp_sh_theme');
	register_setting( 'wp_sh_settings_group', 'wp_sh_auto_links');
	register_setting( 'wp_sh_settings_group', 'wp_sh_class_name');
	register_setting( 'wp_sh_settings_group', 'wp_sh_collapse');
	register_setting( 'wp_sh_settings_group', 'wp_sh_gutter');
	register_setting( 'wp_sh_settings_group', 'wp_sh_first_line');
	register_setting( 'wp_sh_settings_group', 'wp_sh_smart_tabs');
	register_setting( 'wp_sh_settings_group', 'wp_sh_tab_size');
	register_setting( 'wp_sh_settings_group', 'wp_sh_toolbar');
	register_setting( 'wp_sh_settings_group', 'wp_sh_wrap');
	register_setting( 'wp_sh_settings_group', 'wp_sh_legacy');
	register_setting( 'wp_sh_settings_group', 'wp_sh_css');
	add_option('wp_sh_version', '3.0');
	add_option('wp_sh_theme', 'Default');
	add_option('wp_sh_auto_links', 1);
	add_option('wp_sh_class_name', '');
	add_option('wp_sh_collapse', 0);
	add_option('wp_sh_gutter', 1);
	add_option('wp_sh_first_line', '1');
	add_option('wp_sh_smart_tabs', 1);
	add_option('wp_sh_tab_size', '4');
	add_option('wp_sh_toolbar', 1);
	add_option('wp_sh_wrap', 0);
	add_option('wp_sh_legacy', 0);
	add_option('wp_sh_css', 0);
	add_options_page('WP SyntaxHighlighter Options', 'WP SyntaxHighlighter', 10, 'wp-syntaxhighlighter-options', 'wp_sh_options_panel');
}

function wp_sh_setting_link( $links, $file ){
	static $this_plugin;
	if ( ! $this_plugin ) $this_plugin = plugin_basename(__FILE__);
	if ( $file == $this_plugin ){
		$settings_link = '<a href="options-general.php?page=wp-syntaxhighlighter-options">'.__('Settings', 'wp_sh').'</a>';
		array_unshift( $links, $settings_link );
	}  
	return $links;
} 

add_action('wp_print_styles', 'load_style');

//Load css on header
function load_style(){
	global $plugin_url;
	$post = get_the_content();
	$version = get_option('wp_sh_version');
	$theme = get_option('wp_sh_theme');

	if (is_home() || is_singular()) {
		if (get_option('wp_sh_css') == 1) {
			wp_enqueue_style('pre_css', $plugin_url.'pre.css', false, '1.0');
		}
		if ($version == "3.0") {
			wp_enqueue_style('core3', $plugin_url.'syntaxhighlighter3/styles/shCore.css', false, '3.0');
		}
		if ($version == "2.1") {
			wp_enqueue_style('core2', $plugin_url.'syntaxhighlighter2/styles/shCore.css', false, '2.1');
		}
		if ($theme == "Default" && $version == "3.0") {
			wp_enqueue_style('core-default3', $plugin_url.'syntaxhighlighter3/styles/shCoreDefault.css', false, '3.0');
			wp_enqueue_style('theme-default3', $plugin_url.'syntaxhighlighter3/styles/shThemeDefault.css', false, '3.0');
		}
		if ($theme == "Default" && $version == "2.1") {
			wp_enqueue_style('theme-default2', $plugin_url.'syntaxhighlighter2/styles/shThemeDefault.css', false, '2.1');
		}
		if ($theme == "Django" && $version == "3.0") {
			wp_enqueue_style('core-django3', $plugin_url.'syntaxhighlighter3/styles/shCoreDjango.css', false, '3.0');
			wp_enqueue_style('theme-django3', $plugin_url.'syntaxhighlighter3/styles/shThemeDjango.css', false, '3.0');
		}
		if ($theme == "Django" && $version == "2.1") {
			wp_enqueue_style('theme-django2', $plugin_url.'syntaxhighlighter2/styles/shThemeDjango.css', false, '2.1');
		}
		if ($theme == "Eclipse" && $version == "3.0") {
			wp_enqueue_style('core-eclipse3', $plugin_url.'syntaxhighlighter3/styles/shCoreEclipse.css', false, '3.0');
			wp_enqueue_style('theme-eclipse3', $plugin_url.'syntaxhighlighter3/styles/shThemeEclipse.css', false, '3.0');
		}
		if ($theme == "Eclipse" && $version == "2.1") {
			wp_enqueue_style('theme-eclipse2', $plugin_url.'syntaxhighlighter2/styles/shThemeEclipse.css', false, '2.1');
		}
		if ($theme == "Emacs" && $version == "3.0") {
			wp_enqueue_style('core-emacs3', $plugin_url.'syntaxhighlighter3/styles/shCoreEmacs.css', false ,'3.0');
			wp_enqueue_style('theme-emacs3', $plugin_url.'syntaxhighlighter3/styles/shThemeEmacs.css', false, '3.0');
		}
		if ($theme == "Emacs" && $version == "2.1") {
			wp_enqueue_style('core-emacs2', $plugin_url.'syntaxhighlighter3/styles/shThemeEmacs.css', false , '2.1');
		}
		if ($theme == "FadeToGrey" && $version == "3.0") {
			wp_enqueue_style('core-fadetogrey3', $plugin_url.'syntaxhighlighter3/styles/shCoreFadeToGrey.css', false,'3.0');
			wp_enqueue_style('theme-fadetogrey3', $plugin_url.'syntaxhighlighter3/styles/shThemeFadeToGrey.css', false,'3.0');
		}
		if ($theme == "FadeToGrey" && $version == "2.1") {
			wp_enqueue_style('theme-fadetogrey2', $plugin_url.'syntaxhighlighter3/styles/shCoreFadeToGrey.css', false, '2.1');
		}
		if ($theme == "MDUltra" && $version == "3.0") {
			wp_enqueue_style('core-mdultra3', $plugin_url.'syntaxhighlighter3/styles/shCoreMDUltra.css', false, '3.0');
			wp_enqueue_style('theme-mdultra3', $plugin_url.'syntaxhighlighter3/styles/shThemeMDUltra.css', false, '3.0');
		}
		if ($theme == "MDUltra" && $version == "2.1") {
			wp_enqueue_style('theme-default2', $plugin_url.'syntaxhighlighter2/styles/shThemeDefault.css', false, '2.1');
		update_option('wp_sh_theme', 'Default');
		}
		if ($theme == "Midnight" && $version == "3.0") {
			wp_enqueue_style('core-midnight3', $plugin_url.'syntaxhighlighter3/styles/shCoreMidnight.css', false, '3.0');
			wp_enqueue_style('theme-midnight3', $plugin_url.'syntaxhighlighter3/styles/shThemeMidnight.css', false, '3.0');
		}
		if ($theme == "Midnight" && $version == "2.1") {
			wp_enqueue_style('theme-midnight2', $plugin_url.'syntaxhighlighter2/styles/shThemeMidnight.css', false, '2.1');
		}
		if ($theme == "RDark" && $version == "3.0") {
			wp_enqueue_style('core-rdark3', $plugin_url.'syntaxhighlighter3/styles/shCoreRDark.css', false, '3.0');
			wp_enqueue_style('theme-rdark3', $plugin_url.'syntaxhighlighter3/styles/shThemeRDark.css', false, '3.0');
		}
		if ($theme == "RDark" && $version == "2.1") {
			wp_enqueue_style('theme-rdark2', $plugin_url.'syntaxhighlighter2/styles/shThemeRDark.css', false, '2.1');
		}
	}
}

add_action('wp_footer', 'load_scripts_on_footer');

//Load scripts on footer
function load_scripts_on_footer(){
	global $plugin_url;
	$post = get_the_content();
	$version = get_option('wp_sh_version');
	if (preg_match("/<pre[^>]*?brush:[^>]*?>/i", $post) && !is_archive()) {
		if (get_option('wp_sh_auto_links') == 0) {
			$auto_links = 'false';
		} elseif (get_option('wp_sh_auto_links') == 1) {
			$auto_links = 'true';
		}
		if (get_option('wp_sh_collapse') == 0) {
			$collapse = 'false';
		} elseif (get_option('wp_sh_collapse') == 1) {
			$collapse = 'true';
		}
		if (get_option('wp_sh_gutter') == 0) {
			$gutter = 'false';
		} elseif (get_option('wp_sh_gutter') == 1) {
			$gutter = 'true';
		}
		if (get_option('wp_sh_smart_tabs') == 0) {
			$smart_tabs = 'false';
		} elseif (get_option('wp_sh_smart_tabs') == 1) {
			$smart_tabs = 'true';
		}
		if (get_option('wp_sh_toolbar') == 0) {
			$toolbar = 'false';
		} elseif (get_option('wp_sh_toolbar') == 1) {
			$toolbar = 'true';
		}
		if (get_option('wp_sh_wrap') == 0) {
			$wrap = 'false';
		} elseif (get_option('wp_sh_wrap') == 1) {
			$wrap = 'true';
		}
		if (get_option('wp_sh_legacy') == 0) {
			$legacy = '';
		} elseif (get_option('wp_sh_legacy') == 1) {
			$legacy = "dp.SyntaxHighlighter.HighlightAll('code')";
		}
		if ($version == "3.0") {
			echo "\n<script type=\"text/javascript\" src=\"".$plugin_url."syntaxhighlighter3/scripts/shCore.js\"></script>\n";
		} elseif ($version == "2.1") {
			echo "\n<script type=\"text/javascript\" src=\"".$plugin_url."syntaxhighlighter2/scripts/shCore.js\"></script>\n";
		}
		if (get_option('wp_sh_legacy') == 0 && $version == "3.0") {
			echo '';
		} elseif (get_option('wp_sh_legacy') == 1 && $version == "3.0") {
			echo "<script type=\"text/javascript\" src=\"".$plugin_url."syntaxhighlighter3/scripts/shLegacy.js\"></script>\n";
		} elseif (get_option('wp_sh_legacy') == 0 && $version == "2.1") {
			echo '';
		} elseif (get_option('wp_sh_legacy') == 1 && $version == "2.1") {
			echo "<script type=\"text/javascript\" src=\"".$plugin_url."syntaxhighlighter2/scripts/shLegacy.js\"></script>\n";
		}
		if ($version == "3.0") {
			echo "<script type=\"text/javascript\" src=\"".$plugin_url."syntaxhighlighter3/scripts/shAutoloader.js\"></script>\n";
			echo "<script type=\"text/javascript\" src=\"".$plugin_url."syntaxhighlighter3/scripts/shBrushXml.js\"></script>\n";
		} elseif ($version == "2.1") {
			echo "<script type=\"text/javascript\" src=\"".$plugin_url."syntaxhighlighter2/scripts/shBrushCpp.js\"></script>\n";
			echo "<script type=\"text/javascript\" src=\"".$plugin_url."syntaxhighlighter2/scripts/shBrushCSharp.js\"></script>\n";
			echo "<script type=\"text/javascript\" src=\"".$plugin_url."syntaxhighlighter2/scripts/shBrushCss.js\"></script>\n";
			echo "<script type=\"text/javascript\" src=\"".$plugin_url."syntaxhighlighter2/scripts/shBrushDelphi.js\"></script>\n";
			echo "<script type=\"text/javascript\" src=\"".$plugin_url."syntaxhighlighter2/scripts/shBrushJava.js\"></script>\n";
			echo "<script type=\"text/javascript\" src=\"".$plugin_url."syntaxhighlighter2/scripts/shBrushJScript.js\"></script>\n";
			echo "<script type=\"text/javascript\" src=\"".$plugin_url."syntaxhighlighter2/scripts/shBrushPhp.js\"></script>\n";
			echo "<script type=\"text/javascript\" src=\"".$plugin_url."syntaxhighlighter2/scripts/shBrushPython.js\"></script>\n";
			echo "<script type=\"text/javascript\" src=\"".$plugin_url."syntaxhighlighter2/scripts/shBrushRuby.js\"></script>\n";
			echo "<script type=\"text/javascript\" src=\"".$plugin_url."syntaxhighlighter2/scripts/shBrushSql.js\"></script>\n";
			echo "<script type=\"text/javascript\" src=\"".$plugin_url."syntaxhighlighter2/scripts/shBrushVb.js\"></script>\n";
			echo "<script type=\"text/javascript\" src=\"".$plugin_url."syntaxhighlighter2/scripts/shBrushXml.js\"></script>\n";
		}
		if (get_option('wp_sh_legacy') == 1 && $version == "3.0") {
			echo "<script type=\"text/javascript\" src=\"".$plugin_url."syntaxhighlighter3/scripts/shBrushCpp.js\"></script>\n";
			echo "<script type=\"text/javascript\" src=\"".$plugin_url."syntaxhighlighter3/scripts/shBrushCSharp.js\"></script>\n";
			echo "<script type=\"text/javascript\" src=\"".$plugin_url."syntaxhighlighter3/scripts/shBrushCss.js\"></script>\n";
			echo "<script type=\"text/javascript\" src=\"".$plugin_url."syntaxhighlighter3/scripts/shBrushDelphi.js\"></script>\n";
			echo "<script type=\"text/javascript\" src=\"".$plugin_url."syntaxhighlighter3/scripts/shBrushJava.js\"></script>\n";
			echo "<script type=\"text/javascript\" src=\"".$plugin_url."syntaxhighlighter3/scripts/shBrushJScript.js\"></script>\n";
			echo "<script type=\"text/javascript\" src=\"".$plugin_url."syntaxhighlighter3/scripts/shBrushPhp.js\"></script>\n";
			echo "<script type=\"text/javascript\" src=\"".$plugin_url."syntaxhighlighter3/scripts/shBrushPython.js\"></script>\n";
			echo "<script type=\"text/javascript\" src=\"".$plugin_url."syntaxhighlighter3/scripts/shBrushRuby.js\"></script>\n";
			echo "<script type=\"text/javascript\" src=\"".$plugin_url."syntaxhighlighter3/scripts/shBrushSql.js\"></script>\n";
			echo "<script type=\"text/javascript\" src=\"".$plugin_url."syntaxhighlighter3/scripts/shBrushVb.js\"></script>\n";
		}
		if ($version == "3.0") {
			echo "<script type=\"text/javascript\">//<![CDATA[
	SyntaxHighlighter.autoloader(
		\"applescript			".$plugin_url."syntaxhighlighter3/scripts/shBrushAppleScript.js\"
		,\"as3 actionscript3		".$plugin_url."syntaxhighlighter3/scripts/shBrushAS3.js\"
		,\"bash shell			".$plugin_url."syntaxhighlighter3/scripts/shBrushBash.js\"
		,\"cf coldfusion			".$plugin_url."syntaxhighlighter3/scripts/shBrushColdFusion.js\"
		,\"c# c-sharp csharp		".$plugin_url."syntaxhighlighter3/scripts/shBrushCSharp.js\"
		,\"cpp c				".$plugin_url."syntaxhighlighter3/scripts/shBrushCpp.js\"
		,\"css				".$plugin_url."syntaxhighlighter3/scripts/shBrushCss.js\"
		,\"delphi pas pascal		".$plugin_url."syntaxhighlighter3/scripts/shBrushDelphi.js\"
		,\"diff patch			".$plugin_url."syntaxhighlighter3/scripts/shBrushDiff.js\"
		,\"erl erlang			".$plugin_url."syntaxhighlighter3/scripts/shBrushErlang.js\"
		,\"groovy			".$plugin_url."syntaxhighlighter3/scripts/shBrushGroovy.js\"
		,\"js jscript javascript		".$plugin_url."syntaxhighlighter3/scripts/shBrushJScript.js\"
		,\"java				".$plugin_url."syntaxhighlighter3/scripts/shBrushJava.js\"
		,\"jfx javafx			".$plugin_url."syntaxhighlighter3/scripts/shBrushJavaFX.js\"
		,\"perl pl			".$plugin_url."syntaxhighlighter3/scripts/shBrushPerl.js\"
		,\"php				".$plugin_url."syntaxhighlighter3/scripts/shBrushPhp.js\"
		,\"plain text			".$plugin_url."syntaxhighlighter3/scripts/shBrushPlain.js\"
		,\"ps powershell			".$plugin_url."syntaxhighlighter3/scripts/shBrushPowerShell.js\"
		,\"py python			".$plugin_url."syntaxhighlighter3/scripts/shBrushPython.js\"
		,\"rails ror ruby rb		".$plugin_url."syntaxhighlighter3/scripts/shBrushRuby.js\"
		,\"sass scss			".$plugin_url."syntaxhighlighter3/scripts/shBrushSass.js\"
		,\"scala				".$plugin_url."syntaxhighlighter3/scripts/shBrushScala.js\"
		,\"sql				".$plugin_url."syntaxhighlighter3/scripts/shBrushSql.js\"
		,\"vb vbnet			".$plugin_url."syntaxhighlighter3/scripts/shBrushVb.js\"
		,\"xml xhtml xslt html		".$plugin_url."syntaxhighlighter3/scripts/shBrushXml.js\"
	);
	SyntaxHighlighter.defaults['auto-links'] = ".$auto_links.";
	SyntaxHighlighter.defaults['class-name'] = '".get_option('wp_sh_class_name')."';
	SyntaxHighlighter.defaults['collapse'] = ".$collapse.";
	SyntaxHighlighter.defaults['first-line'] = ".get_option('wp_sh_first_line').";
	SyntaxHighlighter.defaults['gutter'] = ".$gutter.";
	SyntaxHighlighter.defaults['smart-tabs'] = ".$smart_tabs.";
	SyntaxHighlighter.defaults['tab-size'] = ".get_option('wp_sh_tab_size').";
	SyntaxHighlighter.defaults['toolbar'] = ".$toolbar.";
	SyntaxHighlighter.config.strings.expandSource = '".__( '+ expand source', 'wp_sh' )."';
	SyntaxHighlighter.config.strings.help = '".__( '?', 'wp_sh' )."';
	SyntaxHighlighter.config.strings.alert = '".__( 'SyntaxHighlighter\n\n', 'wp_sh' )."';
	SyntaxHighlighter.config.strings.noBrush = \"".__( 'Can\'t find brush for: ', 'wp_sh' )."\";
	SyntaxHighlighter.config.strings.brushNotHtmlScript = \"".__( 'Brush wasn\'t configured for html-script option: ', 'wp_sh' )."\";
	SyntaxHighlighter.all();
		".$legacy."
		//]]></script>\n";
		} elseif ($version == "2.1") {
			echo "<script type=\"text/javascript\">//<![CDATA[
	SyntaxHighlighter.config.clipboardSwf = 'syntaxhighlighter2/scripts/clipboard.swf';
	SyntaxHighlighter.defaults['auto-links'] = ".$auto_links.";
	SyntaxHighlighter.defaults['class-name'] = '".get_option('wp_sh_class_name')."';
	SyntaxHighlighter.defaults['collapse'] = ".$collapse.";
	SyntaxHighlighter.defaults['first-line'] = ".get_option('wp_sh_first_line').";
	SyntaxHighlighter.defaults['gutter'] = ".$gutter.";
	SyntaxHighlighter.defaults['smart-tabs'] = ".$smart_tabs.";
	SyntaxHighlighter.defaults['tab-size'] = ".get_option('wp_sh_tab_size').";
	SyntaxHighlighter.defaults['toolbar'] = ".$toolbar.";
	SyntaxHighlighter.defaults['wrap-lines'] = ".$wrap.";
	SyntaxHighlighter.config.strings.expandSource = '".__( 'show source', 'wp_sh' )."';
	SyntaxHighlighter.config.strings.viewSource = '".__( 'view source', 'wp_sh' )."';
	SyntaxHighlighter.config.strings.copyToClipboard = '".__( 'copy to clipboard', 'wp_sh' )."';
	SyntaxHighlighter.config.strings.copyToClipboardConfirmation = '".__( 'The code is in your clipboard now', 'wp_sh' )."';
	SyntaxHighlighter.config.strings.print = '".__( 'print', 'wp_sh' )."';
	SyntaxHighlighter.config.strings.help = '".__( '?', 'wp_sh' )."';
	SyntaxHighlighter.config.strings.alert = '".__( 'SyntaxHighlighter\n\n', 'wp_sh' )."';
	SyntaxHighlighter.config.strings.noBrush = \"".__( 'Can\'t find brush for: ', 'wp_sh' )."\";
	SyntaxHighlighter.config.strings.brushNotHtmlScript = \"".__( 'Brush wasn\'t configured for html-script option: ', 'wp_sh' )."\";
	SyntaxHighlighter.all();
	".$legacy."
	//]]></script>\n";
		}
	} else {
		echo '';
	}
}

//Setting panel
function wp_sh_options_panel(){
	if(!function_exists('current_user_can') || !current_user_can('manage_options')){
			die(__('Cheatin&#8217; uh?'));
	} 
	add_action('in_admin_footer', 'wp_sh_add_admin_footer'. -999);
	?> 
	<div class="wrap">
	<h2>WP SyntaxHighlighter</h2>
	<form method="post" action="options.php">
		<table style="margin-top:20px">
		<?php settings_fields('wp_sh_settings_group'); ?>
			<tr valign="top">
				<th scope="row" align="right"><?php _e('Library version', 'wp_sh') ?></th> 
				<td style="padding-left:10px">
					<?php if (get_option('wp_sh_version') == "3.0") {
						$version_3 = 'selected=\"selected\"';
					} elseif (get_option('wp_sh_version') == "2.1") {
						$version_2 = 'selected=\"selected\"';
					} else {
						$version_3 = '';
						$version_2 = '';
					} ?>
					<select name="wp_sh_version">
						<option value="3.0" <?php echo $version_3; ?>>3.0.83</option>
						<option value="2.1" <?php echo $version_2; ?>>2.1.382</option>
					</select>
					<p><small><?php _e("Choose 'Syntax Highlighter' JavaScript library version. It is important backbone for this plugin. You can also choose older version.", "wp_sh") ?></small></p>
				</td>
			</tr>
			<tr valign="top">
				<th scope="row" align="right"><?php _e('Theme', 'wp_sh') ?></th> 
				<td style="padding-left:10px">
					<?php if (get_option('wp_sh_theme') == "Default") {
						$theme_default = 'selected=\"selected\"';
					} elseif (get_option('wp_sh_theme') == "Django") {
						$theme_django = 'selected=\"selected\"';
					} elseif (get_option('wp_sh_theme') == "Eclipse") {
						$theme_eclipse= 'selected=\"selected\"';
					} elseif (get_option('wp_sh_theme') == "Emacs") {
						$theme_emacs= 'selected=\"selected\"';
					} elseif (get_option('wp_sh_theme') == "FadeToGrey") {
						$theme_fadetogrey= 'selected=\"selected\"';
					} elseif (get_option('wp_sh_theme') == "MDUltra") {
						$theme_mdultra= 'selected=\"selected\"';
					} elseif (get_option('wp_sh_theme') == "Midnight") {
						$theme_midnight= 'selected=\"selected\"';
					} elseif (get_option('wp_sh_theme') == "RDark") {
						$theme_rdark= 'selected=\"selected\"';
					} else {
						$theme_default = '';
						$theme_django =  '';
						$theme_eclipse = '';
						$theme_emacs = '';
						$theme_fadetogrey = '';
						$theme_mdultra = '';
						$theme_midnight = '';
						$theme_rdark = '';
					} ?>
					<select name="wp_sh_theme">
						<option value="Default" <?php echo $theme_default; ?>>Default</option>
						<option value="Django" <?php echo $theme_django; ?>>Django</option>
						<option value="Eclipse" <?php echo $theme_eclipse; ?>>Eclipse</option>
						<option value="Emacs" <?php echo $theme_emacs; ?>>Emacs</option>
						<option value="FadeToGrey" <?php echo $theme_fadetogrey; ?>>FadeToGrey</option>					
						<option value="MDUltra" <?php echo $theme_mdultra; ?>>MDUltra</option>					
						<option value="Midnight" <?php echo $theme_midnight; ?>>Midnight</option>
						<option value="RDark" <?php echo $theme_rdark; ?>>RDark</option>
					</select>
					<p><small><?php _e("Themes for the highlighted elements. 'MDUltra' is not available for ver. 2.1.<br />If you choose 'MDUltra' in ver. 2.1, Theme will be replaced with 'Defaut' theme.", "wp_sh") ?></small></p>
				</td>
			</tr>
			<tr valign="top">
				<th scope="row" align="right"><?php _e('Auto links', 'wp_sh') ?></th>
				<td style="padding-left:10px">
					<?php $auto_links_check = get_option('wp_sh_auto_links') ? ' checked="checked" ' : ''; ?>
					<input type="checkbox" name="wp_sh_auto_links" value="1" <?php echo $auto_links_check; ?>/>
					<p><small><?php _e('URL in the highlighted element will be linked by default.', 'wp_sh') ?></small></p>
				</td>
			</tr>
			<tr valign="top">
				<th scope="row" align="right"><?php _e('Class name', 'wp_sh') ?></th>
				<td style="padding-left:10px">
					<input type="text" name="wp_sh_class_name" value="<?php echo get_option('wp_sh_class_name') ?>" />
					<p><small><?php _e('Enter a custom class for your CSS.', 'wp_sh') ?></small></p>
				</td>
			</tr>
			<tr valign="top">
				<th scope="row" align="right"><?php _e('Collapse', 'wp_sh') ?></th>
				<td style="padding-left:10px">
					<?php $collapse_check = get_option('wp_sh_collapse') ? ' checked="checked" ' : ''; ?>
					<input type="checkbox" name="wp_sh_collapse" value="1" <?php echo $collapse_check; ?>/>
					<p><small><?php _e("The code box will be collapsed by default. If you want to use this option, 'Toolbar' option must be enabled. ", "wp_sh") ?></small></p>
				</td>
			</tr>
			<tr valign="top">
				<th scope="row" align="right"><?php _e('Line number(Gutter)', 'wp_sh') ?></th>
				<td style="padding-left:10px">
					<?php $gutter_check = get_option('wp_sh_gutter') ? ' checked="checked" ' : ''; ?>
					<input type="checkbox" name="wp_sh_gutter" value="1" <?php echo $gutter_check; ?>/>
					<p><small><?php _e('Line number(Gutter) will be shown by default.', 'wp_sh') ?></small></p>
				</td>
			</tr>
			<tr valign="top">
				<th scope="row" align="right"><?php _e('Starting line number', 'wp_sh') ?></th>
				<td style="padding-left:10px">
					<input type="text" name="wp_sh_first_line" size="2" value="<?php echo get_option('wp_sh_first_line') ?>" />
					<p><small><?php _e('Enter starting line number for the line numbering(Gutter).', 'wp_sh') ?></small></p>
				</td>
			</tr>
			<tr valign="top">
				<th scope="row" align="right"><?php _e('Smart tabs', 'wp_sh') ?></th>
				<td style="padding-left:10px">
					<?php $smart_tabs_check = get_option('wp_sh_smart_tabs') ? ' checked="checked" ' : ''; ?>
					<input type="checkbox" name="wp_sh_smart_tabs" value="1" <?php echo $smart_tabs_check; ?>/>
					<p><small><?php _e("Indent by 'tab' will be optimized by default.", "wp_sh") ?></small></p>
				</td>
			</tr>
			<tr valign="top">
				<th scope="row" align="right"><?php _e('Tab size', 'wp_sh') ?></th>
				<td style="padding-left:10px">
					<input type="text" name="wp_sh_tab_size" size="2" value="<?php echo get_option('wp_sh_tab_size') ?>" />
					<p><small><?php _e("Tab size for 'Smart tabs' feature.", "wp_sh") ?></small></p>
				</td>
			</tr>
			<tr valign="top">
				<th scope="row" align="right"><?php _e('Toolbar', 'wp_sh') ?></th>
				<td style="padding-left:10px">
					<?php $toolbar_check = get_option('wp_sh_toolbar') ? ' checked="checked" ' : ''; ?>
					<input type="checkbox" name="wp_sh_toolbar" value="1" <?php echo $toolbar_check; ?>/>
					<p><small><?php _e('Toolbar will be shown by default.', 'wp_sh') ?></small></p>
				</td>
			</tr>
			<tr valign="top">
				<th scope="row" align="right"><?php _e('Wrap lines', 'wp_sh') ?></th>
				<td style="padding-left:10px">
					<?php $toolbar_check = get_option('wp_sh_wrap') ? ' checked="checked" ' : ''; ?>
					<input type="checkbox" name="wp_sh_wrap" value="1" <?php echo $toolbar_check; ?>/>
					<p><small><?php _e('Only for ver.2.1. Long lines will be wrapped automatically by default.', 'wp_sh') ?></small></p>
				</td>
			</tr>
			<tr valign="top">
				<th scope="row" align="right"><?php _e('Legacy mode', 'wp_sh') ?></th>
				<td style="padding-left:10px">
					<?php $legacy_check = get_option('wp_sh_legacy') ? ' checked="checked" ' : ''; ?>
					<input type="checkbox" name="wp_sh_legacy" value="1" <?php echo $legacy_check; ?>/>
					<p><small><?php _e("Support old style 'pre' tag in Ver. 1.5.<br />As a result, 'autoloader' for language files will be disabled and all language definition files for ver. 1.5 will be loaded.<br />That may impact performance.", "wp_sh") ?></small></p>
				</td>
			</tr>
			<tr valign="top">
				<th scope="row" align="right"><?php _e('CSS for <code>&lt;pre&gt;</code> tag', 'wp_sh') ?></th>
				<td style="padding-left:10px">
					<?php $css_check = get_option('wp_sh_css') ? ' checked="checked" ' : ''; ?>
					<input type="checkbox" name="wp_sh_css" value="1" <?php echo $css_check; ?>/>
					<p><small><?php _e("If it is some time before your code highlighted, Unbeautiful code block will appear for a while.<br />This CSS will define its visual layout. Your code block may look some more good.", "wp_sh") ?></small></p>
				</td>
			</tr>
		 </table>
		<p class="submit">
		  <input type="submit" name="Submit" value="<?php _e('Save Changes', 'wp_sh') ?>" />
		</p>
	</form>
<?php }
?>